-- So we're going to launch additional activities from our mussion but hide them from activity selection menu 
-- to avoid player confusion. The whole idea was explained by TheLastBanana and Mail2345 with the help of Roast Veg
-- asking useful wuestions. This is not a reference design it's just my vision of implementation of such tricky thing
-- as multiple missions inside one activity.
-- 
-- Unfortunately B24 does not offer any tools to hide your activity from the activity selection screen. The whole idea
-- is that you have to define just a single activity and launch all your additionsl missions from inside of that
-- activity. But this time you can't just use StartActivity because you don't have (and if you have, they will be
-- visible) any activities except the single one (this).
-- 
-- This activity is something like a bootloader, it does not do anything itself, it just launches other missions stored
-- in external Lua files. Since we don't have any activities to launch the whole process becomes a little complicated.
-- Comments to StartActivity explain everything. You sholud also check MissionTut_08.rte/Scenes/Scripts/MissionTut_08_01.lua
-- to watch what changes you need to add to your mission code to make it ready for launch this way.
function MissionLauncher:StartActivity()
	print("START! -- MissionLauncher:StartActivity()!");

	-- Obtain the unique zone to avoid mapping your main activity
	-- to any available scene. Although we don't do anything here
	-- wee need to get this zone, or our campaign will be playable
	-- on ANY scene available and we certainly don't want it to happen
	self.Zone = SceneMan.Scene:GetArea("TUT8_AntiBugZone");
	
	-- Define base path to our mission scripts just to avoid mistakes
	-- This is a global varaible and it's since it's set it's available to
	-- everyone furing until CC is restarted. We'll use them to pass arguments
	-- to this launcher
	BASE_PATH = "MissionTut_08.rte/Scenes/Scripts/"

	-- First we need to check if we got here from the activity selection screen or from
	-- one of our missions which was switched to another. Remember that we get here every time
	-- we need to switch missions. This is our only StartActivity function for all missions.
	-- First check if TRANSFER_IN_PROGRESS exists. If it's not, then we've entered here
	-- from the ActivitySelection screen. If so, tell the script that it's not a transfer.
	if TRANSFER_IN_PROGRESS == nil then
		TRANSFER_IN_PROGRESS = false
	end
	
	-- If TRANSFER_IN_PROGRESS is set to true then we've got here from mission (let's call it initiator) 
	-- willing to transfer to some other mission. Initiator MUST set TRANSFER_IN_PROGRESS to true before
	-- it gives control to this activity to finish actual transfer. The point is that if player will reset
	-- his current activity we may be stuck with missions to which we transfered for the last time, and we'll
	-- need to restart CC to reset global variables which tell this activity where we want to go today.
	-- So if we don't see TRANSFER_IN_PROGRESS set by previously maunched script we decide that we were started
	-- from activity selection screen.
	if not TRANSFER_IN_PROGRESS then
		-- Reset all previouly set scenes and scripts before launch since we're starting clean
		SCENE_TO_LAUNCH = nil
		SCRIPT_TO_LAUNCH = nil
	end
	-- On first launch we need to launch some mission. It sgolud be your first mission in a campaign
	-- or UI or whatever decides which mission should be run next bu reading save files and such.
	-- We're just launching the first of two simple example mission to start.
	if SCENE_TO_LAUNCH == nil then
		SCENE_TO_LAUNCH = "MissionTut_08_01"
	end

	-- And here we specify the script that will handle all the events in our mission. This is just a slightly
	-- modified standard mission script.
	if SCRIPT_TO_LAUNCH == nil then
		SCRIPT_TO_LAUNCH = BASE_PATH.."MissionTut_08_01.lua"
	end
	
	-- Reset transfer flag
	TRANSFER_IN_PROGRESS = false
	
	-- Here we're loading our mission script. The trick is that Lua will replace all functions defined in this activitiy
	-- with ones that defined in our script file. Note, that we're not leaving THIS activity, we're just changing it's code
	-- to our mission code
	dofile(SCRIPT_TO_LAUNCH)
	-- Load a scene for our mission to which we want to transfer control
	SceneMan:LoadScene(SCENE_TO_LAUNCH , true)
	-- That's all, from here we're almost inside our mission execution loop. We just need to wait for single UpdateActivity
	-- execution and voila!
	-- Proceed to MissionTut_08_01.lua to see what's next
end
-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------
-- This function is called when mission is paused
function MissionLauncher:PauseActivity(pause)
    print("PAUSE! -- MissionLauncher:PauseActivity()!");
end
-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------
function MissionLauncher:EndActivity()
    print("END! -- MissionLauncher:EndActivity()!");
end
-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------
function MissionLauncher:UpdateActivity()
	-- Old UpdateActivity is called once before our loaded code starts working
	print("Mission launcher - Update Once!")
end
