-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------
function MissionLauncher:StartActivity()
	print("MissionTut_08_01:StartActivity()!");

	-- Because this code is launched in a non standard way we have to lauch StartActivity ourselves
	-- from our UpdateActivity loop. And of course we need to do it just once. So we're playing with flags
	-- to find out if it's first launch or not
	if self.IsInitialized == nil then
		self.IsInitialized = false
	end

	-- Exit if we're already initialized everything
	if self.IsInitialized then 
		return
	end

	-- Standard mission initialization routines
	self.braindead = {};
	self.AssignedBrains = {};
	
	self.CPUTeam = Activity.TEAM_2;
	self.PlayerTeam = Activity.TEAM_1;
	self.RogueTeam = -1;
	
	self.TransferZone = SceneMan.Scene:GetArea("TUT8_TransferZone");
	
	for player = 0, self.PlayerCount - 1 do
		if not self:GetPlayerBrain(player) then
			self.braindead[player] = false;
			local brain = CreateAHuman("Brain Robot" , "base.rte");
			brain.Pos = Vector(150 + player * 30 , 550);
			brain.AIMode = Actor.AIMODE_SENTRY;
			self.AssignedBrains[player] = brain;

			MovableMan:AddActor(brain);
			self:SetPlayerBrain(brain, player);
			SceneMan:SetScroll(self:GetPlayerBrain(player).Pos, player);
			self:SetObservationTarget(self:GetPlayerBrain(player).Pos, player);
			self:SwitchToActor(brain, player, self.PlayerTeam);
		end
	end	
	
	-- Don't forget to tell this script that we're initialized
	self.IsInitialized = true
end
-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------
-- This function is called when mission is paused
function MissionLauncher:PauseActivity(pause)
    print("PAUSE! -- MissionTut_08_01:PauseActivity()!");
end
-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------
function MissionLauncher:EndActivity()
    print("END! -- MissionTut_08_01:EndActivity()!");
end
-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------
function MissionLauncher:UpdateActivity()
	-- Just check for intialization flags in update loop to avoid unnecessary function calls during all the mission
	if self.IsInitialized == nil then
		self.IsInitialized = false
	end
	
	if not self.IsInitialized then
		--Init mission if we're still not
		self:StartActivity()
	end

	-- If we have everything initialized then we can start checking for brains and win loose conditions and whatever
	self:DoBrainSelection();
	
   	self:ClearObjectivePoints();

	self:AddObjectivePoint("Go to mission 2", Vector(792 , 500), self.PlayerTeam, GameActivity.ARROWDOWN);
	
	for actor in MovableMan.Actors do
		if  self.TransferZone:IsInside(actor.Pos) then
			-- So our actor is inside transfer zone, it's time to warp him to another misison
			-- Set scene we want to jump into
			SCENE_TO_LAUNCH = "MissionTut_08_02"
			-- Set script we want to control our mission
			SCRIPT_TO_LAUNCH = BASE_PATH.."MissionTut_08_02.lua"
			-- Don't forget to tell that we're transferring or we'll end up playing default mission once again
			TRANSFER_IN_PROGRESS = true
			
			-- Stop current activity
			ActivityMan:EndActivity();
			-- Restart our main activity. It will read whate we've put into global variables and
			-- start mission we want
			ActivityMan:StartActivity("GAScripted" , "MissionTut_08");			
			break
		end
	end

	
	self:YSortObjectivePoints();
end
-----------------------------------------------------------------------------------------
-- Brain selection and gameover conditions check
-----------------------------------------------------------------------------------------
function MissionLauncher:DoBrainSelection()
	if not (self.ActivityState == Activity.OVER) then
		-- print ("DoBrainSelection")
		for player = 0, self.PlayerCount - 1 do
			local team = self:GetTeamOfPlayer(player);
	
			local brain = self:GetPlayerBrain(player);
			if not brain or not MovableMan:IsActor(brain) or not brain:HasObjectInGroup("Brains") then
				self:SetPlayerBrain(nil, player);
				local newBrain = MovableMan:GetUnassignedBrain(team);
				if newBrain and self.braindead[player] == false then
					self:SetPlayerBrain(newBrain, player);
					self:SwitchToActor(newBrain, player, team);
				else
					FrameMan:SetScreenText("Commander died!", player, 100, -1, false);
					self.braindead[player] = true;
					
					self.WinnerTeam = self:OtherTeam(team);
					ActivityMan:EndActivity();
				end
			else
				self:SetObservationTarget(brain.Pos, player)
			end -- 
		end --for
	end --if
end
-----------------------------------------------------------------------------------------
-- That's all folks!
-----------------------------------------------------------------------------------------



































